

set -ex



test -f "${PREFIX}/include/oniggnu.h"
test -f "${PREFIX}/include/onigposix.h"
test -f "${PREFIX}/include/oniguruma.h"
test -f "${PREFIX}/lib/libonig.a"
test -f "${PREFIX}/lib/libonig.so"
test -f "${PREFIX}/lib/pkgconfig/oniguruma.pc"
onig-config --version
exit 0
